/*
 * "motion.c" - A test program demonstrating the use of glAccum() for
 *              motion blur.
 */

#include <GLUT/glut.h>
#include <stdlib.h>

GLfloat rotation = 0.0;

/*
 * 'reshape_scene()' - Change the size of the scene...
 */

void reshape_scene(GLsizei width,    /* I - Width of the window in pixels */
              GLsizei height)   /* I - Height of the window in pixels */
{
    /*
     * Reset the current viewport and perspective transformation...
     */
    
    glViewport(0, 0, width, height);
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    gluPerspective(22.5, (float)width / (float)height, 0.1, 1000.0);
    glMatrixMode(GL_MODELVIEW);
}

/*
 * 'draw_scene()' - Draw a scene containing a cube with a sphere in
 *                  front of it.
 */

void draw_scene(void)
{
    GLfloat       frame = 0.0;
    static float   red_light[4] = { 1.0, 0.0, 0.0, 1.0 };
    static float   red_pos[4] = { 1.0, 1.0, 1.0, 0.0 };
    static float blue_light[4] = { 0.0, 0.0, 1.0, 1.0 };
    static float   blue_pos[4] = { -1.0, -1.0, -1.0, 0.0 };
    
    /*
     * Enable drawing features that we need...
     */
    
    glEnable(GL_DEPTH_TEST);
    glEnable(GL_LIGHTING);
    glEnable(GL_LIGHT0);
    glEnable(GL_LIGHT1);
    glShadeModel(GL_SMOOTH);
    
    /*
     * Clear the color and depth buffers...
     */
    
    glClearColor(0.0, 0.0, 0.0, 0.0);
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    
    /*
     * Draw the cube and sphere in different colors...
     *
     * We have positioned two lights in this scene.  The first is red and
     * located above, to the right, and behind the viewer.  The second
     * is blue and located below, to the left, and in front of the viewer.
     */
    
    glLightfv(GL_LIGHT0, GL_DIFFUSE, red_light);
    glLightfv(GL_LIGHT0, GL_POSITION, red_pos);
    
    glLightfv(GL_LIGHT1, GL_DIFFUSE, blue_light);
    glLightfv(GL_LIGHT1, GL_POSITION, blue_pos);
    
    
    /*
     * Draw the objects ? times starting at the current rotation...
     FIX THIS CODE/////////////////////////
     */
    
    //for (frame = 0.0; frame <= 20.0; frame ++)
    {
        glPushMatrix();
        glTranslatef(0.0, 0.0, -20.0);
        glRotatef(rotation - frame, 0.0, 1.0, 0.0);
        
        glPushMatrix();
        glTranslatef(-1.0, 0.0, 0.0);
        glutSolidSphere(1.0, 50, 50);
        glPopMatrix();
        
        glPushMatrix();
        glTranslatef(1.0, 0.0, 0.0);
        glRotatef(15.0, 0.0, 1.0, 0.0);
        glRotatef(15.0, 0.0, 0.0, 1.0);
        glutSolidCube(2.0);
        glPopMatrix();
        glPopMatrix();
        
        /*
         * Accumulate ?% the first time, ?% every other time...
         FIX THIS CODE/////////////////////////
         */
        
    }
    
    /*
     * Copy the accumulated results back to the color buffer...
     FIX THIS CODE////////////////////////////
     */
    

    glutSwapBuffers();
}

/*
 * 'rotate_objects()' - Rotate while we are idle...
 */

void rotate_objects(void)
{
    rotation += 0.5;
    if (rotation >= 360.0)
        rotation -= 360.0;
    
    draw_scene();
}

//keyboard function for escape key to quit
void keyboard(unsigned char key, int x, int y)
{
#pragma unused (x,y)
    switch (key) {
            
        case 27:
            exit(0);
            break;
        default:
            break;
    }
}


/*
 * 'main()' - Initialize the window and display the scene until the user
 *            presses the ESCape key.
 */

// Mainline function
int main(int argc, char **argv)
{
    glutInit(&argc, argv);
    glutInitDisplayMode(GLUT_DOUBLE| GLUT_RGBA | GLUT_DEPTH |GLUT_ACCUM);
    glutInitWindowSize (500, 500);
    glutInitWindowPosition (50, 50);
    glutCreateWindow("Motion");
    glutReshapeFunc(reshape_scene);
    glutDisplayFunc(draw_scene);
    glutKeyboardFunc (keyboard);
    glutIdleFunc(rotate_objects);
    glutMainLoop();
    return 0;
}